@@ -19,6 +19,7 @@ Filterer = Callable[[T], T]
 Mapper = Callable[[T], Optional[R]]
 FlatMapper = Callable[[Streamable], 'Stream']
 Comparator = Callable[[T, T], Union[bool, Awaitable[bool]]]
+Consumer = Callable[[T], T]
 
 # Terminals
 Accumulator = Callable[[T, Union[T, R]], Union[T, R]]
@@ -38,6 +39,10 @@ class Stream:
         self._stream: AsyncGenerator = _normalize(streamable)
         self._chain: List[Callable] = []
 
+    @staticmethod
+    def empty() -> 'Stream':
+        return Stream([])
+
     # Intermediaries
     def filter(self, predicate: Predicate) -> 'Stream':
         async def fn(iterable: AsyncGenerator) -> AsyncGenerator:
@@ -115,6 +120,18 @@ class Stream:
         self._chain.append(fn)
         return self
 
+    def peek(self, consumer: Consumer) -> 'Stream':
+        async def fn(iterable: AsyncGenerator) -> AsyncGenerator:
+            async for i in iterable:
+                if iscoroutinefunction(consumer):
+                    await consumer(i)
+                else:
+                    consumer(i)
+                yield i
+
+        self._chain.append(fn)
+        return self
+
     # Terminals
     def _compose(self, intermediaries: List[Callable], iterable: AsyncGenerator) -> AsyncGenerator:
         if len(intermediaries) == 0:
@@ -149,9 +166,14 @@ class Stream:
         return await self._min_max(comparator)
 
     async def min(self, comparator: Comparator) -> Optional[T]:
-        def negative_comparator(x, y):
-            return not comparator(x, y)
-        return await self._min_max(negative_comparator)
+        if iscoroutinefunction(comparator):
+            async def negative_comparator(x, y):
+                return not await comparator(x, y)
+            return await self._min_max(negative_comparator)
+        else:
+            def negative_comparator(x, y):
+                return not comparator(x, y)
+            return await self._min_max(negative_comparator)
 
     async def _min_max(self, comparator: Comparator) -> Optional[T]:
         found = None
@@ -167,3 +189,17 @@ class Stream:
                 if n and comparator(n, found):
                     found = n
         return found
+
+    async def all_match(self, predicate: Predicate) -> bool:
+        async for n in self._compose(self._chain, self._stream):
+            if iscoroutinefunction(predicate):
+                if await predicate(n):
+                    continue
+                else:
+                    return False
+            else:
+                if predicate(n):
+                    continue
+                else:
+                    return False
+        return True
